API_URL = 'https://usapi.cv.ford.com/api'  # US Connected Vehicle api
VEHICLE_URL = 'https://services.cx.ford.com/api'
USER_URL = 'https://api.mps.ford.com/api'
TOKEN_URL = 'https://sso.ci.ford.com/oidc/endpoint/default/token'
APP_ID = '71A3AD0A-CF46-4CCF-B473-FC7FE5BC4592'
